@@ -57,12 +57,13 @@ class SubscriptionSummary(models.Model):
     created = models.DateTimeField()
     updated = models.DateTimeField()
     salesperson = models.CharField(max_length=200)
-    product = models.CharField(max_length=200)
+    product = models.CharField(max_length=200, null=True)
 
     # customer details
     customer_name = models.CharField(max_length=200)
-    customer_account_number = models.CharField(max_length=50, unique=True)
-    customer_xero_guid = models.UUIDField(blank=True)
+    customer_account_number = models.CharField(max_length=50, db_index=True)
+    # NOTE(William to Aidan): Are we sure this should be nullable?...we are storing nulls here for whatever reason.
+    customer_xero_guid = models.UUIDField(blank=True, null=True)
     customer_primary_contact_name = models.CharField(max_length=200)
     customer_primary_contact_email = models.CharField(max_length=200)
     customer_accounts_contact_name = models.CharField(max_length=200)
@@ -131,7 +132,7 @@ class RecurringCreditSummary(models.Model):
 
     subscription_guid = models.UUIDField()
     customer_name = models.CharField(max_length=200)
-    customer_account_number = models.CharField(max_length=50, unique=True)
+    customer_account_number = models.CharField(max_length=50)
     currency = models.CharField(max_length=3)
 
     start_date = models.DateField()
@@ -157,10 +158,10 @@ class ChangeSummary(models.Model):
 
     subscription_guid = models.UUIDField()
     customer_name = models.CharField(max_length=200)
-    customer_account_number = models.CharField(max_length=50, unique=True)
+    customer_account_number = models.CharField(max_length=50)
     currency = models.CharField(max_length=3)
 
-    change_type = models.TextField()
+    change_type = models.TextField(null=True)
     date = models.DateField()
     note = models.TextField(blank=True)
     amount = models.DecimalField(max_digits=10, decimal_places=2)
@@ -177,15 +178,15 @@ class ChangeSummary(models.Model):
 class ChargeSummary(models.Model):
     """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitally."""
 
-    last_synced = models.DateTimeField()
+    last_synced = models.DateTimeField(null=True) # Reflecting reality
 
-    created = models.DateTimeField()
-    updated = models.DateTimeField()
+    created = models.DateTimeField(null=True) # Reflecting reality
+    updated = models.DateTimeField(null=True) # Reflecting reality
     requestor = models.CharField(max_length=200)
 
     subscription_guid = models.UUIDField()
     customer_name = models.CharField(max_length=200)
-    customer_account_number = models.CharField(max_length=50, unique=True)
+    customer_account_number = models.CharField(max_length=50)
     currency = models.CharField(max_length=3)
 
     itemcode = models.CharField(max_length=20)
@@ -217,8 +218,8 @@ class WorkspaceSummary(models.Model):
     last_synced = models.DateTimeField()
 
     guid = models.UUIDField(primary_key=True)
-    name = models.CharField(max_length=50, unique=True)
-    customer_account_number = models.CharField(max_length=50, unique=True)
+    name = models.CharField(max_length=50)
+    customer_account_number = models.CharField(max_length=50)
     subscription_guid = models.UUIDField()
 
     class Meta:
@@ -229,15 +230,16 @@ class WorkspaceSummary(models.Model):
         db_table = 'subscriptionmanager"."billing_workspace_summary'
 
 
+
 class XeroContactSummary(models.Model):
     """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitaly."""
 
     last_synced = models.DateTimeField()
 
-    customer_name = models.CharField(max_length=200)
-    customer_account_number = models.CharField(max_length=50)
-    customer_first_name = models.CharField(max_length=100)
-    customer_last_name = models.CharField(max_length=100)
+    customer_name = models.CharField(max_length=200, null=True)
+    customer_account_number = models.CharField(max_length=50, null=True)
+    customer_first_name = models.CharField(max_length=100, null=True)
+    customer_last_name = models.CharField(max_length=100, null=True)
 
     class Meta:
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
@@ -265,8 +267,9 @@ class XeroInvoiceSummary(models.Model):
     status = models.CharField(max_length=50)
     currency = models.CharField(max_length=3)
     currency_rate = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
-    is_sent = models.BooleanField()
-    repeating_invoice_guid = models.UUIDField()
+    is_sent = models.BooleanField(default=False)
+    # TODO(@Aidan)... ?????
+    repeating_invoice_guid = models.UUIDField(null=True)
     amount_due = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
     amount_paid = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
     fully_paid_on_date = models.DateField(blank=True, null=True)
@@ -277,4 +280,3 @@ class XeroInvoiceSummary(models.Model):
 
         default_permissions = ()
         db_table = 'subscriptionmanager"."billing_xero_invoice_summary'
-
